@@ -1,4 +1,5 @@
-from typing import Dict, List, Optional, TypedDict, Union
+from typing import Dict, List, Literal, Optional, TypedDict, Union
+
 
 class ActivitiesChannelType(TypedDict, total=False):
     ccid: int
@@ -16,35 +17,46 @@ class ActivitiesChannelListType(TypedDict, total=False):
     id: str
     version: str
 
-class ActivitesTVType(TypedDict):
+
+class ActivitesTVType(TypedDict, total=False):
     channel: ActivitiesChannelType
     channelList: ActivitiesChannelListType
 
+
 class ChannelsCurrentType(TypedDict):
     id: str
 
+
 class ComponentType(TypedDict):
     packageName: str
     className: str
 
+
 class ApplicationIntentType(TypedDict, total=False):
     extras: Dict
     component: ComponentType
     action: str
 
-class ApplicationType(TypedDict):
+
+class ApplicationType(TypedDict, total=False):
     label: str
     intent: ApplicationIntentType
     order: int
     id: str
     type: str
 
+
 class ApplicationsType(TypedDict):
     version: int
     applications: List[ApplicationType]
 
 
-class FavoriteType(TypedDict, total=True):
+class FavoriteChannelType(TypedDict):
+    ccid: int
+    preset: str
+
+
+class FavoriteListType(TypedDict, total=False):
     id: str
     version: Union[int, str]
     parentId: str
@@ -53,15 +65,18 @@ class FavoriteType(TypedDict, total=True):
     virtual: bool
     modifiable: bool
     name: str
+    channels: List[FavoriteChannelType]
+
 
 class ChannelType(TypedDict, total=False):
     ccid: int
     preset: str
     name: str
 
+
 class ChannelListType(TypedDict, total=False):
     id: str
-    version: int
+    version: Union[int, str]
     listType: str
     medium: str
     active: bool
@@ -69,11 +84,14 @@ class ChannelListType(TypedDict, total=False):
     modifiable: bool
     Channel: List[ChannelType]
 
+
 ChannelsType = Dict[str, ChannelType]
 
-class ChannelDbTv(TypedDict):
+
+class ChannelDbTv(TypedDict, total=False):
     channelLists: List[ChannelListType]
-    favoriteLists: List[FavoriteType]
+    favoriteLists: List[FavoriteListType]
+
 
 class JsonFeaturesType(TypedDict, total=False):
     editfavorites: List[str]
@@ -88,17 +106,24 @@ class JsonFeaturesType(TypedDict, total=False):
     channels: List[str]
     mappings: List[str]
 
+
 class SystemFeaturesType(TypedDict, total=False):
     tvtype: str
     content: List[str]
     tvsearch: str
     pairing_type: str
     secured_transport: str
-    companion_screen: str
+    companion_screen: Union[str, bool]
+
+    # stored here on saphi
+    os_type: str
+
+
 class SystemFeaturingType(TypedDict):
     jsonfeatures: JsonFeaturesType
     systemfeatures: SystemFeaturesType
 
+
 class SystemType(TypedDict, total=False):
     menulanguage: str
     name: str
@@ -115,26 +140,82 @@ class SystemType(TypedDict, total=False):
     api_version: Dict
     featuring: SystemFeaturingType
     notifyChange: str
+
+    # here on android systems
     os_type: str
 
+
 class SourceType(TypedDict, total=False):
     name: str
 
 
 SourcesType = Dict[str, SourceType]
 
+
 class SourceCurrentType(TypedDict):
     id: str
 
-class ContextType1(TypedDict):
+
+class ContextType(TypedDict, total=False):
     data: str
     level1: str
     level2: str
     level3: str
 
-class ContextType2(TypedDict):
+    # in some older context these exists
     activity: str
     menu: str
     Recording: str
 
-ContextType = Union[ContextType1, ContextType2]
+
+AmbilightPixelType = Dict[Literal["r", "g", "b"], int]
+
+AmbilightSideType = Dict[str, AmbilightPixelType]
+
+AmbilightLayerType = Dict[Literal["left", "top", "right", "bottom"], AmbilightSideType]
+
+AmbilightLayersType = Dict[str, AmbilightLayerType]
+
+
+class AmbilightSupportedStyleType(TypedDict, total=False):
+    styleName: str
+    algorithms: List[str]
+    maxTuning: int
+    maxSpeed: int
+
+    # Extension to get the non expert modes too
+    menuSettings: List[str]
+
+
+class AmbilightSupportedStylesType(TypedDict):
+    supportedStyles: List[AmbilightSupportedStyleType]
+
+
+class AmbilightColorType(TypedDict):
+    hue: int
+    saturation: int
+    brightness: int
+
+
+class AmbilightAudioSettingsType(TypedDict):
+    color: AmbilightColorType
+    colorDelta: AmbilightColorType
+    tuning: int
+    algorithm: str
+
+
+class AmbilightColorSettingsType(TypedDict):
+    color: AmbilightColorType
+    colorDelta: AmbilightColorType
+    speed: int
+    algorithm: str
+
+
+class AmbilightCurrentConfiguration(TypedDict, total=False):
+    styleName: str
+    isExpert: bool
+    menuSetting: str
+    stringValue: str
+
+    audioSettings: AmbilightAudioSettingsType
+    colorSettings: AmbilightColorSettingsType
